OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Kan ikke skrive til «config»-mappen!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Dette kan vanligvis løses ved å gi webserveren skrivetilgang til config-katalogen.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Men hvis du foretrekker å holde config.php filen skrivebeskyttet, angir du alternativet \"config_is_read_only\" til sant i den.",
    "See %s" : "Se %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Applikasjon %1$s er ikke til stede eller har en ikke-kompatibel versjon med denne serveren. Vennligst undersøk apps-katalogen.",
    "Sample configuration detected" : "Eksempeloppsett oppdaget",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Det ble oppdaget at eksempeloppsettet er blitt kopiert. Dette kan ødelegge installasjonen din og støttes ikke. Les dokumentasjonen før du gjør endringer i config.php",
    "The page could not be found on the server." : "Siden ble ikke funnet på serveren.",
    "%s email verification" : "%s e-postbekreftelse",
    "Email verification" : "E-postbekreftelse",
    "Click the following button to confirm your email." : "Klikk på følgende knapp for å bekrefte e-posten din.",
    "Click the following link to confirm your email." : "Klikk på følgende lenke for å bekrefte e-posten din.",
    "Confirm your email" : "Bekreft din e-post",
    "Other activities" : "Andre aktiviteter",
    "%1$s and %2$s" : "%1$s og %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s og %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s og %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s og %5$s",
    "Education bundle" : "Utdanningspakke",
    "Enterprise bundle" : "Bedrifts-pakke",
    "Groupware bundle" : "Gruppevare-pakke",
    "Hub bundle" : "Hub-pakke",
    "Public sector bundle" : "Pakke for offentlig sektor",
    "Social sharing bundle" : "Sosialdelings-pakke",
    "PHP %s or higher is required." : "PHP %s eller nyere kreves.",
    "PHP with a version lower than %s is required." : "PHP med en versjon lavere enn %s kreves.",
    "%sbit or higher PHP required." : "%sbit eller høyere PHP kreves",
    "The following architectures are supported: %s" : "Følgende arkitekturer støttes: %s.",
    "The following databases are supported: %s" : "Følgende databaser støttes: %s.",
    "The command line tool %s could not be found" : "Kommandolinjeverktøyet %s ble ikke funnet",
    "The library %s is not available." : "Biblioteket %s er ikke tilgjengelig.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Bibliotek %1$s med en versjon høyere enn %2$s kreves - tilgjengelig versjon %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Bibliotek %1$s med en versjon lavere enn %2$s kreves - tilgjengelig versjon %3$s.",
    "The following platforms are supported: %s" : "Følgende plattformer støttes: %s.",
    "Server version %s or higher is required." : "Serverversjon %s eller høyere kreves.",
    "Server version %s or lower is required." : "Serverversjon %s eller lavere kreves.",
    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Innlogget konto må være administrator, underadministrator eller ha fått spesiell rett til å få tilgang til denne innstillingen.",
    "Logged in account must be an admin or sub admin" : "Innlogget konto må være administrator eller en underadministrator.",
    "Logged in account must be an admin" : "Innlogget konto må være administrator",
    "Wiping of device %s has started" : "Sikker sletting av enhet %s er startet",
    "Wiping of device »%s« has started" : "Sikker sletting av enhet \"%s\" er startet",
    "»%s« started remote wipe" : "\"%s\" startet sikker fjernsletting",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Enhet eller applikasjon »%s« har startet den eksterne og sikre slettingsprosessen. Du vil motta en ny e-post når prosessen er fullført.",
    "Wiping of device %s has finished" : "Sikker sletting av enhet %s er ferdig",
    "Wiping of device »%s« has finished" : "Sikker sletting av enhet \"%s\" er ferdig",
    "»%s« finished remote wipe" : "\"%s\" fullførte sikker fjernsletting",
    "Device or application »%s« has finished the remote wipe process." : "Enhet eller applikasjon \"%s\" er ferdig med den eksterne og sikre slettingsprosessen.",
    "Remote wipe started" : "Fjernsletting startet",
    "A remote wipe was started on device %s" : "En fjernsletting ble startet på enhet %s",
    "Remote wipe finished" : "Fjernsletting ferdig",
    "The remote wipe on %s has finished" : "Fjernslettingen på %s er ferdig",
    "Authentication" : "Autentisering",
    "Unknown filetype" : "Ukjent filtype",
    "Invalid image" : "Ugyldig bilde",
    "Avatar image is not square" : "Avatarbilde er ikke firkantet",
    "Files" : "Filer",
    "View profile" : "Vis profil",
    "_%nh_::_%nh_" : ["%nh","%nh"],
    "Local time: %s" : "Lokal tid: %s",
    "today" : "i dag",
    "tomorrow" : "I morgen",
    "yesterday" : "i går",
    "_in %n day_::_in %n days_" : ["om én dag","om %n dager"],
    "_%n day ago_::_%n days ago_" : ["%n dag siden","%n dager siden"],
    "next month" : "neste måned",
    "last month" : "forrige måned",
    "_in %n month_::_in %n months_" : ["neste måned","om %n måneder"],
    "_%n month ago_::_%n months ago_" : ["for %n måned siden","for %n måneder siden"],
    "next year" : "neste år",
    "last year" : "forrige år",
    "_in %n year_::_in %n years_" : ["neste år","om %n år"],
    "_%n year ago_::_%n years ago_" : ["%n år siden","%n år siden"],
    "_in %n hour_::_in %n hours_" : ["om %n time","om én timer"],
    "_%n hour ago_::_%n hours ago_" : ["for %n time siden","for %n timer siden"],
    "_in %n minute_::_in %n minutes_" : ["om ett minutt","om %n minutter"],
    "_%n minute ago_::_%n minutes ago_" : ["for %n minutt siden","for %n minutter siden"],
    "in a few seconds" : "om noen sekunder",
    "seconds ago" : "for få sekunder siden",
    "Empty file" : "Tom fil",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul med ID: %s finnes ikke. Skru den på i app-innstillingene eller kontakt en administrator.",
    "Dot files are not allowed" : "Punktum-filer er ikke tillatt",
    "%1$s (renamed)" : "%1$s (har fått nytt navn)",
    "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" er et forbudt fil- eller mappenavn.",
    "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" er et forbudt prefiks for fil- eller mappenavn.",
    "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" er ikke tillatt i et fil- eller mappenavn.",
    "\"%1$s\" is a forbidden file type." : "\"%1$s\" er en forbudt filtype.",
    "Filenames must not end with \"%1$s\"." : "Filnavn må ikke slutte med \"%1$s\".",
    "Invalid parent path" : "Ugyldig overordnet bane",
    "File already exists" : "Filen finnes allerede",
    "Invalid path" : "Ugyldig filbane",
    "Failed to create file from template" : "Oppretting av fil fra mal feilet",
    "Templates" : "Maler",
    "Path contains invalid segments" : "Banen inneholder ugyldige segmenter",
    "Filename is a reserved word" : "Filnavnet er et reservert ord",
    "Filename contains at least one invalid character" : "Filnavnet innehold minst et ugyldig tegn",
    "Filename is too long" : "Filnavnet er for langt",
    "Empty filename is not allowed" : "Tomt filnavn er ikke tillatt",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Appen \"%s\" kan ikke installeres på grunn av at appinfo-filen ikke kan leses.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Appen \"%s\" kan ikke installeres fordi det ikke er kompatibel med denne serverversjonen.",
    "__language_name__" : "Norsk bokmål",
    "This is an automatically sent email, please do not reply." : "Dette er en automatisk sendt e-post, ikke svar.",
    "Help & privacy" : "Hjelp og personvern",
    "Appearance and accessibility" : "Utseende og tilgjengelighet",
    "Apps" : "Apper",
    "Personal settings" : "Personlige innstillinger",
    "Administration settings" : "Administrasjonsinnstillinger",
    "Settings" : "Innstillinger",
    "Log out" : "Logg ut",
    "Accounts" : "Kontoer",
    "Bluesky" : "Bluesky",
    "Email" : "E-post",
    "Mail %s" : "E-post til %s",
    "Fediverse" : "Fediverse",
    "View %s on the fediverse" : "Se %s på fediverse",
    "Phone" : "Telefon",
    "Call %s" : "Ring %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Se %s på Twitter",
    "Website" : "Nettsted",
    "Visit %s" : "Besøk %s",
    "Address" : "Adresse",
    "Profile picture" : "Profilbilde",
    "About" : "Om",
    "Display name" : "Visningsnavn",
    "Headline" : "Overskrift",
    "Organization" : "Organisering",
    "Role" : "Rolle",
    "Pronouns" : "Pronomen",
    "Unknown account" : "Ukjent konto",
    "Additional settings" : "Flere innstillinger",
    "Enter the database Login and name for %s" : "Skriv inn databasens pålogging og navn for %s",
    "Enter the database Login for %s" : "Skriv inn databasens pålogging for %s",
    "Enter the database name for %s" : "Skriv inn databasens navn for %s",
    "You cannot use dots in the database name %s" : "Du kan ikke bruke punktum i databasenavnet %s",
    "MySQL Login and/or password not valid" : "MySQL-pålogging og/eller passord ikke gyldig",
    "You need to enter details of an existing account." : "Du må legge in detaljene til en eksisterende konto.",
    "Oracle connection could not be established" : "Klarte ikke å etablere forbindelse til Oracle",
    "Oracle Login and/or password not valid" : "Oracle-pålogging og/eller passord ikke gyldig",
    "PostgreSQL Login and/or password not valid" : "PostgreSQL-pålogging og/eller passord ikke gyldig",
    "For the best results, please consider using a GNU/Linux server instead." : "For beste resultat, vurder å bruke en GNU/Linux-server i stedet.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Det ser ut for at %s-instansen kjører i et 32-bit PHP-miljø med open_basedir satt opp i php.ini. Dette vil føre til problemer med filer over 4 GB og frarådes på det sterkeste.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Fjern innstillingen open_basedir i php.ini eller bytt til 64-bit PHP.",
    "Set an admin Login." : "Angi en admin-pålogging.",
    "Set an admin password." : "Sett et admin-passord.",
    "Cannot create or write into the data directory %s" : "Kan ikke opprette eller skrive i datakatalogen %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Delings-server %s må implementere grensesnittet OCP\\Share_Backend",
    "Sharing backend %s not found" : "Delings-server %s ikke funnet",
    "Sharing backend for %s not found" : "Delings-server for %s ikke funnet",
    "%1$s shared %2$s with you" : "%1$s delte %2$s med deg",
    "Open %s" : "Åpne %s",
    "%1$s via %2$s" : "%1$s via %2$s",
    "%1$s shared %2$s with you and wants to add:" : "%1$s delte %2$s med deg og ønsker å legge til:",
    "%1$s shared %2$s with you and wants to add" : "%1$s delte %2$s med deg og ønsker å legge til",
    "%s added a note to a file shared with you" : "%s la til et notat i en fil som er delt med deg",
    "Passwords are enforced for link and mail shares" : "Passord håndheves for koblings- og e-postdelinger",
    "Share recipient is not a valid user" : "Delingsmottakeren er ikke en gyldig bruker",
    "Share recipient is not a valid group" : "Delingsmottakeren er ikke en gyldig gruppe",
    "Share recipient should be empty" : "Delingsmottakeren skal være tom",
    "Share recipient should not be empty" : "Delingsmottakeren skal ikke være tom",
    "Share recipient is not a valid circle" : "Delingsmottakeren er ikke en gyldig sirkel",
    "Unknown share type" : "Ukjent ressurstype",
    "Cannot share with yourself" : "Kan ikke dele med deg selv",
    "You cannot share your root folder" : "Du kan ikke dele rot-mappen din",
    "You are not allowed to share %s" : "Du har ikke lov til å dele %s",
    "Valid permissions are required for sharing" : "Gyldige tillatelser kreves for deling",
    "Cannot increase permissions of %s" : "Kan ikke øke tillatelser for %s",
    "Files cannot be shared with delete permissions" : "Filer kan ikke deles med slett-rettigheter",
    "Files cannot be shared with create permissions" : "Filer kan ikke deles med opprettingstillatelser",
    "Expiration date is in the past" : "Utløpsdato er i fortid",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Kan ikke sette utløpsdato mer enn %n dag i fremtiden","Kan ikke sette utløpsdato mer enn %n dager i fremtiden"],
    "Sharing is only allowed with group members" : "Deling er kun tillatt med gruppemedlemmer",
    "Sharing %s failed, because this item is already shared with the account %s" : "Deling av %s feilet, fordi dette elementet er allerede delt med kontoen %s",
    "Group \"%s\" does not exist" : "Gruppen «%s» finnes ikke.",
    "The requested share does not exist anymore" : "Forespurt ressurs finnes ikke lenger",
    "The requested share comes from a disabled user" : "Den forespurte delingen kommer fra en deaktivert bruker",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Brukeren ble ikke opprettet fordi brukergrensen er nådd. Sjekk varslene dine for å finne ut mer.",
    "Could not find category \"%s\"" : "Kunne ikke finne kategori \"%s\"",
    "Input text" : "Inndatatekst",
    "The input text" : "Inndatateksten",
    "Sunday" : "Søndag",
    "Monday" : "Mandag",
    "Tuesday" : "Tirsdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Lørdag",
    "Sun." : "Søn.",
    "Mon." : "Man.",
    "Tue." : "Tir.",
    "Wed." : "Ons.",
    "Thu." : "Tirs.",
    "Fri." : "Fre.",
    "Sat." : "Lør.",
    "Su" : "Sø",
    "Mo" : "Ma",
    "Tu" : "Ti",
    "We" : "On",
    "Th" : "To",
    "Fr" : "Fr",
    "Sa" : "Lø",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "Mars",
    "April" : "April",
    "May" : "Mai",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "Desember",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Mai.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Des.",
    "A valid password must be provided" : "Oppgi et gyldig passord",
    "The Login is already being used" : "Påloggingen er allerede i bruk",
    "Could not create account" : "Kunne ikke opprette konto",
    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Kun følgende tegn er tillatt i en pålogging: \"a-z\", \"A-Z\", \"0-9\", mellomrom og \"_.@-'\"",
    "A valid Login must be provided" : "En gyldig pålogging må angis",
    "Login contains whitespace at the beginning or at the end" : "Pålogging inneholder mellomrom i begynnelsen eller på slutten",
    "Login must not consist of dots only" : "Pålogging kan ikke bare bestå av punktum",
    "Login is invalid because files already exist for this user" : "Påloggingen er ugyldig fordi det finnes allerede filer for denne brukeren.",
    "Account disabled" : "Konto deaktivert",
    "Login canceled by app" : "Innlogging avbrutt av app",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "App \"%1$s\" kan ikke installeres fordi følgende avhengigheter ikke er møtt: %2$s.",
    "a safe home for all your data" : "et sikkert hjem for alle dine data",
    "Application is not enabled" : "Appen er ikke aktivert",
    "Authentication error" : "Autentikasjonsfeil",
    "Token expired. Please reload page." : "Symbol utløpt. Last inn siden på nytt.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Ingen databasedrivere (sqlite, mysql, or postgresql) installert.",
    "Cannot write into \"config\" directory." : "Kan ikke skrive i \"config\"-katalogen.",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Dette kan vanligvis ordnes ved å gi webserveren skrivetilgang til config-katalogen. Se %s.",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Men hvis du foretrekker å holde config.php filen skrivebeskyttet, angir du alternativet \"config_is_read_only\" til sant i den. Se %s.",
    "Cannot create \"data\" directory." : "Kan ikke opprette \"data\"-katalogen.",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Dette kan vanligvis ordnes ved å gi webserveren skrivetilgang til rotkatalogen. Se %s.",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Tillatelser kan vanligvis ordnes ved å gi webserveren skrivetilgang til rotkatalogen. Se %s.",
    "Your data directory is not writable." : "Datakatalogen kan ikke skrives til.",
    "Setting locale to %s failed." : "Innstilling av nasjonal innstilling til %s feilet.",
    "Please install one of these locales on your system and restart your web server." : "Installer en av disse nasjonale innstillingene på systemet ditt, og start webserveren på nytt.",
    "PHP module %s not installed." : "PHP-modul %s er ikke installert.",
    "Please ask your server administrator to install the module." : "Be server-administratoren om å installere modulen.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP-innstilling \"%s\" er ikke satt til \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Ved å endre denne innstillingen i php.ini gjør at Nextcloud vil kjøre igjen.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Det ser ut til at at PHP er satt opp til å fjerne innebygde doc-blokker. Dette gjør at flere av kjerneapplikasjonene blir utilgjengelige.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dette forårsakes sannsynligvis av hurtiglager/akselerator, som f.eks. Zend OPcache eller eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP-moduler har blitt installert, men de listes fortsatt som fraværende?",
    "Please ask your server administrator to restart the web server." : "Be server-administratoren om å starte webserveren på nytt.",
    "The required %s config variable is not configured in the config.php file." : "Den nødvendige %s konfigurasjonsvariabelen er ikke konfigurert i config.php-filen.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Be serveradministratoren din om å sjekke Nextcloud-konfigurasjonen.",
    "Your data directory is readable by other people." : "Datakatalogen din er lesbar for andre personer.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Endre tillatelsene til 0770 slik at katalogen ikke kan listes av andre personer.",
    "Your data directory must be an absolute path." : "Datakatalogen din må være en absolutt sti.",
    "Check the value of \"datadirectory\" in your configuration." : "Sjekk verdien for \"datadirectory\" i konfigurasjonen din.",
    "Your data directory is invalid." : "Datakatalogen din er ugyldig.",
    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "Sørg for at det er en fil som heter \"%1$s\" i roten av datakatalogen. Den skal ha innholdet: \"%2$s\"",
    "Action \"%s\" not supported or implemented." : "Handling \"%s\" ikke støttet eller implementert.",
    "Authentication failed, wrong token or provider ID given" : "Autentisering feilet, feil token eller leverandør-ID gitt",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Parametere mangler for å fullføre forespørselen. Manglende parametere: \"%s\".",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ID \"%1$s\" allerede brukt av cloud federation-leverandør \"%2$s\".",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Cloud Federation-leverandør med ID: \"%s\" finnes ikke.",
    "Could not obtain lock type %d on \"%s\"." : "Klarte ikke å låse med type %d på \"%s\".",
    "Storage unauthorized. %s" : "Lager uautorisert: %s",
    "Storage incomplete configuration. %s" : "Ikke komplett oppsett for lager. %s",
    "Storage connection error. %s" : "Tilkoblingsfeil for lager. %s",
    "Storage is temporarily not available" : "Lagring er midlertidig utilgjengelig",
    "Storage connection timeout. %s" : "Tidsavbrudd ved tilkobling av lager: %s",
    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "For å la denne kontrollen kjøre, må du sørge for at webserveren din kan koble til seg selv. Derfor må den kunne løse og koble til minst en dens 'trusted_domains' eller 'overwrite.cli.url'. Denne feilen kan være et resultat av ikke-DNS-samsvar på serversiden eller en regel for utgående brannmur.",
    "Images" : "Bilder",
    "Question" : "Spørsmål",
    "System prompt" : "Systemledetekst",
    "Define rules and assumptions that the assistant should follow during the conversation." : "Definer regler og antagelser som assistenten skal følge under samtalen.",
    "Chat history" : "Chathistorikk",
    "Transcribe audio" : "Transkriber lyd",
    "Transcribe the things said in an audio" : "Transkriber tingene som blir sagt i en lyd",
    "Audio input" : "Lydinndata",
    "The audio to transcribe" : "Lyden å transkribere",
    "Transcription" : "Transkripsjon",
    "The transcribed text" : "Den transkriberte teksten",
    "Confirmation" : "Bekreftelse",
    "Chat message" : "Chatmelding",
    "Context write" : "Kontekstskriving",
    "Writes text in a given style based on the provided source material." : "Skriver tekst i en gitt stil basert på det angitte kildematerialet.",
    "Writing style" : "Skrivestil",
    "Demonstrate a writing style that you would like to immitate" : "Demonstrer en skrivestil som du ønsker å etterligne",
    "Source material" : "Kildemateriale",
    "The content that would like to be rewritten in the new writing style" : "Innholdet som ønsker å bli omskrevet i den nye skrivestilen",
    "Generated text" : "Generert tekst",
    "The generated text with content from the source material in the given style" : "Den genererte teksten med innhold fra kildematerialet i den gitte stilen",
    "Emoji generator" : "Emoji generator",
    "Takes text and generates a representative emoji for it." : "Tar tekst og genererer en representativ emoji for den.",
    "The text to generate an emoji for" : "Teksten for å generere en emoji for",
    "Generated emoji" : "Generert emoji",
    "The generated emoji based on the input text" : "Den genererte emojien basert på inndatateksten",
    "Optical character recognition" : "Optisk tegngjenkjenning",
    "Generate image" : "Generer bilde",
    "Generate an image from a text prompt" : "Generere et bilde fra en tekstledetekst",
    "Prompt" : "Spør",
    "Describe the image you want to generate" : "Beskriv bildet du vil generere",
    "Number of images" : "Antall bilder",
    "How many images to generate" : "Hvor mange bilder som skal genereres",
    "Output images" : "Utdatabilder",
    "The generated images" : "De genererte bildene",
    "Free text to text prompt" : "Fritekst til tekstmelding",
    "Runs an arbitrary prompt through a language model that returns a reply" : "Kjører en vilkårlig forespørsel gjennom en språkmodell som returnerer et svar",
    "Describe a task that you want the assistant to do or ask a question" : "Beskriv en oppgave du vil at assistenten skal gjøre, eller still et spørsmål",
    "Generated reply" : "Generert svar",
    "The generated text from the assistant" : "Den genererte teksten fra assistenten",
    "Chat" : "Chat",
    "Chat with the assistant" : "Chat med assistenten",
    "The history of chat messages before the current message, starting with a message by the user" : "Loggen over chatmeldinger før gjeldende melding, som starter med en melding fra brukeren",
    "Response message" : "Svarmelding",
    "The generated response as part of the conversation" : "Den genererte responsen som en del av samtalen",
    "Formalize text" : "Formaliser tekst",
    "Takes a text and makes it sound more formal" : "Tar en tekst og får den til å høres mer formell ut",
    "Write a text that you want the assistant to formalize" : "Skriv en tekst som du vil at assistenten skal formalisere",
    "Formalized text" : "Formalisert tekst",
    "The formalized text" : "Den formaliserte teksten",
    "Generate a headline" : "Generer en overskrift",
    "Generates a possible headline for a text." : "Genererer en mulig overskrift for en tekst.",
    "Original text" : "Opprinnelig tekst",
    "The original text to generate a headline for" : "Den opprinnelige teksten som skal genereres en overskrift for",
    "The generated headline" : "Den genererte overskriften",
    "Text" : "Tekst",
    "Reformulate text" : "Omformulere tekst",
    "Takes a text and reformulates it" : "Tar en tekst og omformulerer den",
    "Write a text that you want the assistant to reformulate" : "Skriv en tekst som du vil at assistenten skal omformulere",
    "Reformulated text" : "Omformulert tekst",
    "The reformulated text, written by the assistant" : "Den omformulerte teksten, skrevet av assistenten",
    "Simplify text" : "Forenkle tekst",
    "Takes a text and simplifies it" : "Tar en tekst og forenkler den",
    "Write a text that you want the assistant to simplify" : "Skriv en tekst som du vil at assistenten skal forenkle",
    "Simplified text" : "Forenklet tekst",
    "The simplified text" : "Den forenklede teksten",
    "Summarize" : "Oppsummere",
    "Summarizes a text" : "Oppsummerer en tekst",
    "The original text to summarize" : "Den opprinnelige teksten å oppsummere",
    "Summary" : "Oppsummering",
    "The generated summary" : "Det genererte sammendraget",
    "Extract topics" : "Trekk ut emner",
    "Extracts topics from a text and outputs them separated by commas" : "Trekker ut emner fra en tekst og sender dem ut atskilt med komma.",
    "The original text to extract topics from" : "Den opprinnelige teksten å trekke ut emner fra",
    "Topics" : "Emner",
    "The list of extracted topics" : "Listen over uttrekte emner",
    "Translate" : "Oversette",
    "Translate text from one language to another" : "Oversett tekst fra ett språk til et annet",
    "Origin text" : "Opprinnelig tekst",
    "The text to translate" : "Teksten å oversette",
    "Origin language" : "Opprinnelig språk",
    "The language of the origin text" : "Språket til originalteksten",
    "Target language" : "Målspråk",
    "The desired language to translate the origin text in" : "Ønsket språk å oversette opprinnelsesteksten til",
    "Result" : "Resultat",
    "The translated text" : "Den oversatte teksten",
    "Free prompt" : "Ledig ledetekst",
    "Runs an arbitrary prompt through the language model." : "Kjører en vilkårlig ledetekst gjennom språkmodellen.",
    "Generate headline" : "Generer overskrift",
    "Summarizes text by reducing its length without losing key information." : "Oppsummerer tekst ved å redusere lengden uten å miste nøkkelinformasjon.",
    "Extracts topics from a text and outputs them separated by commas." : "Trekker ut emner fra en tekst og sender dem ut atskilt med komma.",
    "Organisation" : "Organisasion",
    "Cannot write into \"apps\" directory." : "Kan ikke skrive i \"apps\"-katalogen.",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Dette kan vanligvis løses ved å gi webserveren skrivetilgang til apps-katalogen eller deaktivere App Store i konfigurasjonsfilen.",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> er satt til <code>%s</code> istedenfor den forventede verdien <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "For å fikse dette problemet sett <code>mbstring.func_overload</code> til <code>0</code> i php.ini."
},
"nplurals=2; plural=(n != 1);");
